package
Version:
v0.0.0-...-f68c1a0
Opens a new window with list of versions in this module.
Published: Feb 6, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Pair[A, B any] struct {
A A
B B
}
func NewPair[A, B any](a A, b B) Pair[A, B]
func (p Pair[A, B]) Unpack() (A, B)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.